@@ -1,29 +1,27 @@
-import bz2
 import csv
-import gzip
-import lzma
 import os
 import shutil
 import sys
 import uuid
 from subprocess import Popen
-
+import logging
 import pandas as pd
-import py7zr
-from pyunpack import Archive
 from tika import parser
 
 from texta_parsers.email_parser import EmailParser
 from texta_parsers.settings import META_FIELD
-from texta_parsers.tools import rar_extractor, tar_extractor, utils
+from texta_parsers.tools import utils
 from texta_parsers.tools.extension import Extension
 from texta_parsers.tools.scanner import DocScanner
+from texta_parsers.tools.archive import ArchiveExtractor
 from . import exceptions
-# for digidoc parser
-from .exceptions import UnsupportedFileError
 
 
-FNULL = open(os.devnull, "w")
+logging.basicConfig(
+    format='%(levelname)s %(asctime)s: %(message)s',
+    datefmt='%d.%m.%Y %H:%M:%S',
+    level=logging.INFO
+)
 
 
 class DocParser:
@@ -33,6 +31,7 @@ class DocParser:
                  save_mails=False,
                  save_documents=False,
                  parse_attachments=True,
+                 allowed_attachment_extensions=Extension.KNOWN_EXTENSIONS,
                  save_path="parsed_files",
                  temp_dir="",
                  languages=["est", "eng", "rus"],
@@ -44,14 +43,16 @@ class DocParser:
         :param: bool save_mails: Whether to save emails.
         :param: bool save_documents: Whether to save files (other than emails and attachments).
         :param: bool parse_attachments: Whether to parse the content of attached files in email.
+        :param: set allowed_attachment_extensions: Limit the extensions used in attachment parsing to remove images etc. if required.
         :param: str save_path: Base directory for files to be saved permanently.
         :param: str temp_dir: Base directory for files to be saved temporary.
         :param: [str] languages: Tika OCR languages.
-        :param: int max_file_size: Maximum file size in MBs that will be parsed.
+        :param: int max_file_size: Maximum file size in MBs that will be parsed. Does not apply to mailbox files.
         :param: [bool] ignore_digidoc: Whether digidoc containers should be ignored.
         """
 
         self.save_attachments = save_attachments
+        self.allowed_attachment_extensions = allowed_attachment_extensions
         self.save_mails = save_mails
         self.save_documents = save_documents
         self.parse_attachments = parse_attachments
@@ -91,110 +92,6 @@ class DocParser:
         return file_path
 
 
-    def _extract_digidoc(self, input_path, output_dir, extracted=[]):
-        """
-        Extracts contents from digidoc. Works recursively.
-        """
-        cmd = f"digidoc-tool open {input_path} --extractAll={output_dir}"
-        p = Popen(cmd, shell=True, stdout=FNULL)
-        p.wait()
-        # generate full paths for the output
-        extracted_docs = os.listdir(output_dir)
-        extracted_docs = [os.path.join(output_dir, file_name) for file_name in extracted_docs]
-        # extract further if digidocs in output
-        for extracted_doc in extracted_docs:
-            ext = Extension.predict(extracted_doc)
-            if ext in Extension.DIGIDOC_EXTENSIONS:
-                self._extract_digidoc(extracted_doc, output_dir, extracted=extracted)
-            else:
-                extracted.append(extracted_doc)
-        return extracted
-
-
-    def _extract_rar(self, input_path, output_dir):
-        rar_extractor.extract_rar_file(input_path, output_dir)
-
-
-    def _extract_tar(self, input_path, output_dir):
-        tar_extractor.extract_tar_file(input_path, output_dir)
-
-
-    def _extract_7z(self, input_path, output_path):
-        with py7zr.SevenZipFile(input_path, mode='r') as z:
-            z.extractall(path=output_path)
-
-
-    def _extract_bz2(self, input_path, output_path):
-        output_loc = os.path.join(output_path, "out.decompressed")
-        with open(output_loc, 'wb') as out_file, bz2.BZ2File(input_path, 'rb') as in_file:
-            for data in iter(lambda: in_file.read(100 * 1024), b''):
-                out_file.write(data)
-
-
-    def _extract_gz(self, input_path, output_path):
-        output_loc = os.path.join(output_path, "out.decompressed")
-        with open(output_loc, 'wb') as out_file, gzip.GzipFile(input_path, 'rb') as in_file:
-            for data in iter(lambda: in_file.read(100 * 1024), b''):
-                out_file.write(data)
-
-
-    def _extract_xz(self, input_path, output_path):
-        output_loc = os.path.join(output_path, "out.decompressed")
-        with open(output_loc, 'wb') as out_file, lzma.LZMAFile(input_path, 'rb') as in_file:
-            for data in iter(lambda: in_file.read(100 * 1024), b''):
-                out_file.write(data)
-
-
-    def _extract_archive(self, input_path, output_dir, extension):
-        """
-        Extracts contents from archives. Works recursively.
-        """
-        # create temporary output directory
-        # just to be safe, because file names may repeat
-        output_dir = os.path.join(output_dir, uuid.uuid4().hex)
-        if not os.path.exists(output_dir):
-            os.makedirs(output_dir)
-        # extract with digidoc client
-        if extension in Extension.DIGIDOC_EXTENSIONS:
-            self._extract_digidoc(input_path, output_dir)
-        elif extension == ".rar":
-            self._extract_rar(input_path, output_dir)
-        elif extension == ".tar":
-            self._extract_tar(input_path, output_dir)
-        elif extension == ".7z":
-            self._extract_7z(input_path, output_dir)
-        # Note: as the name of the file in the bz2 archive is unknow,
-        # extension prediction relies entirely on magic, which tends to fail
-        # in some cases (e.g digidoc)
-        elif extension == ".bz2":
-            self._extract_bz2(input_path, output_dir)
-        elif extension == ".gz":
-            self._extract_gz(input_path, output_dir)
-        elif extension == ".xz":
-            self._extract_xz(input_path, output_dir)
-        else:
-            archive = Archive(input_path)
-            archive.extractall(output_dir)
-        # generate full paths for the output
-        extracted_paths = os.listdir(output_dir)
-        extracted_paths = [os.path.join(output_dir, file_name) for file_name in extracted_paths]
-        # extract further if archives in output
-        for extracted_path in extracted_paths:
-            if os.path.isdir(extracted_path):
-                ### TODO: HOLY SHIT ITS A DIRECTORY INSIDE AN ARCHIVE!
-                pass
-            else:
-                try:
-                    extracted_extension = Extension.predict(extracted_path)
-                    if extracted_extension in Extension.ARCHIVE_EXTENSIONS:
-                        for doc in self._extract_archive(extracted_path, output_dir, extracted_extension):
-                            yield doc
-                    else:
-                        yield {"path": extracted_path, "extension": extracted_extension}
-                except UnsupportedFileError as e:
-                    yield {"path": extracted_path, "extension": None}
-
-
     def remove_temp_dir(self):
         """
         Removes temp directory path.
@@ -280,15 +177,19 @@ class DocParser:
 
             if not os.path.exists(save_path):
                 os.makedirs(save_path)
+            
+            attachment_path = attachment[META_FIELD].get("path")
+            
+            if attachment_path:
+                extension = attachment[META_FIELD].get("extension")
+                if not extension:
+                    extension = Extension.predict(attachment_path)
+                    attachment[META_FIELD]["extension"] = extension
 
-            # generate random filename for attachment if for some reason it is missing
-            if (attachment["filename"] == ""):
-                filename = os.path.join(save_path, uuid.uuid4().hex + attachment[META_FIELD]["extension"])
-            else:
-                filename = os.path.join(save_path, attachment["filename"])
+                filename = os.path.join(save_path, uuid.uuid4().hex + extension)
 
-            shutil.copyfile(attachment[META_FIELD]["path"], filename)
-            attachment[META_FIELD]["location"] = filename
+                shutil.copyfile(attachment[META_FIELD]["path"], filename)
+                attachment[META_FIELD]["location"] = filename
         return True
 
 
@@ -301,8 +202,10 @@ class DocParser:
                 os.makedirs(save_path)
 
             filename = os.path.join(save_path, uuid.uuid4().hex + extension)
-            shutil.copyfile(meta["path"], filename)
-            meta["location"] = filename
+            path = meta.get("path")
+            if path:
+                shutil.copyfile(meta["path"], filename)
+                meta["location"] = filename
         return True
 
 
@@ -347,8 +250,10 @@ class DocParser:
             if (len(parsed_attachment) > 1):
                 sub_attachment["id"] = sub_attachment["id"] + "_" + str(ix + 1)
 
-            extracted_attachments.append(sub_attachment)
-
+            # remove files we should not parse
+            if sub_attachment[META_FIELD].get("extension") in self.allowed_attachment_extensions:
+                extracted_attachments.append(sub_attachment)
+ 
         return extracted_attachments
 
 
@@ -384,7 +289,7 @@ class DocParser:
 
             # in case of an arcive, extract all files from it
             if extension in Extension.ARCHIVE_EXTENSIONS:
-                docs_to_parse = list(self._extract_archive(file_path, self.temp_dir, extension))
+                docs_to_parse = list(ArchiveExtractor().extract(file_path, self.temp_dir, extension))
             else:
                 docs_to_parse.append({"path": file_path, "extension": extension})
 
@@ -393,23 +298,22 @@ class DocParser:
 
             # parse all files
             for meta in docs_to_parse:
+                # check size for anything but mailboxes, because they are huge
                 if (not self._file_size_ok(self.max_file_size, meta)):
                     meta.setdefault("errors", [])
                     meta["errors"].append("File too large for parsing.")
                     yield {META_FIELD: meta}
-
+                # deal with mailboxes etc
                 # email parser handles all the errors and logs uncaught
                 elif (meta["extension"] in Extension.EMAIL_EXTENSIONS):
                     parser = EmailParser(tmp_folder=self.temp_dir, save_path=self.save_path)
                     generator = parser.parse(meta["path"], save_mails=self.save_mails)
 
                     for msg_dict, attachment_dicts in generator:
-                        msg_dict[META_FIELD] = meta.copy()  # add metadata to email dictionary
-
+                        msg_dict[META_FIELD] = meta.copy()  
                         # attachments in attachment_dicts are not parsed and the field content only contains raw payload in bytes.
                         # thus we need to call parse function on each content to get the text.
                         # moreover, each payload can potentially contain multiple files if it is an archive, for instance.
-
                         extracted_attachments = []
                         for attachment in attachment_dicts:
                             attachment.setdefault(META_FIELD, {})  # Ensure that the meta field exists.
