@@ -4,14 +4,12 @@ import os
 import shutil
 from random import getrandbits
 
-import magic
-
 from texta_parsers.settings import META_FIELD
 from texta_parsers.tools.message import AttachmentParser, BodyParser, HeaderParser
 from texta_parsers.tools.pst_extractor import check_readpst_exists, extract_pst_file
+from texta_parsers.tools.extension import Extension
 
 
-SUPPORTED_MAIL_FORMATS = [".mbox", ".pst", ".eml"]
 logging.basicConfig(
     format='%(levelname)s %(asctime)s: %(message)s',
     datefmt='%d.%m.%Y %H:%M:%S',
@@ -22,18 +20,16 @@ logging.basicConfig(
 class EmailParser():
     """ 
     # Parameters 
-    max_attachment_size (int): in megabytes. Content from larger attachments won't be parsed (optional, default: 10)
-    num_threads (int): number of threads in case of multiprocessing, (optional, default: 1)
     tmp_folder (string): folder for temporal files, (optional, default: "tmp")
     save_path (string): folder for non-temporal files, (optional, default: "parsed_files")
+    supported_attachment_extensions (set): only parse known extensions, (optional)
     """
 
-
-    def __init__(self, num_threads=1, tmp_folder="tmp", save_path="parsed_files"):
-        self.num_threads = num_threads
+    def __init__(self, tmp_folder="tmp", save_path="parsed_files", supported_attachment_extensions=Extension.KNOWN_EXTENSIONS):
         self.tmp_folder = tmp_folder
         self.save_path = save_path
         self.save_mails = None
+        self.supported_attachment_extensions = supported_attachment_extensions
         if not check_readpst_exists():
             raise FileNotFoundError("Readpst not found. Can not initialize parser.")
 
@@ -106,6 +102,7 @@ class EmailParser():
             for attachment in attachments:
                 # replace parent_id the id of correct parent
                 attachment["parent_id"] = msg_data["id"]
+
             attachments.append(msg_data)
 
         # parse other message/rfc822 attachments if there is any
@@ -116,7 +113,6 @@ class EmailParser():
 
                     if (self.save_mails):
                         # save sub-mails if required as we won't see it's payload later
-                        print("saving mail with id", nested_attachments[-1]["id"])
                         filepath = self._save_mail_as_eml(payload, msg_id + "/" + nested_attachments[-1]["id"])
                         if (filepath):
                             nested_attachments[-1]["location"] = filepath
@@ -162,67 +158,25 @@ class EmailParser():
         return msg_data, attachments
 
 
-    @staticmethod
-    def _try_get_file_beginning(file):
-        if isinstance(file, bytes):
-            return file[:2048]
-        else:
-            try:
-                return open(file, "rb").read(2048)
-            except:
-                return None
-
-
     def _get_files(self, path):
         """Returns a list of email files from given folder (recursive) or a list with single file if input is file.
         """
         results = []
         if os.path.isfile(path):
-            file_beginning = EmailParser._try_get_file_beginning(path)
-            res = self._file_is_mail(path, file_beginning)
+            res = Extension.file_is_mail(path)
             if (res):
                 results.append((path, res))
         else:
             for dirpath, _, filenames in os.walk(path):
                 for filename in filenames:
                     full_file = os.path.join(dirpath, filename)
-
-                    file_beginning = EmailParser._try_get_file_beginning(full_file)
-                    res = self._file_is_mail(filename, file_beginning)
+                    res = Extension.file_is_mail(full_file)
                     if (res):
                         results.append((full_file, res))
 
         return results
 
 
-    @staticmethod
-    def _file_is_mail(filename, file_beginning):
-        ext = os.path.splitext(filename)[1]
-        if ext in SUPPORTED_MAIL_FORMATS:
-            return ext
-
-        if (file_beginning == None):
-            return
-        elif (EmailParser._has_msg_mimetype(file_beginning)):
-            return ".eml"
-        elif (EmailParser._begins_like_mbox(file_beginning)):
-            return ".mbox"
-
-
-    @staticmethod
-    def _has_msg_mimetype(input):
-        mimetype = magic.from_buffer(input, mime=True)
-        return mimetype == "message/rfc822"
-
-
-    @staticmethod
-    def _begins_like_mbox(input):
-        try:
-            return input.decode().startswith("From ")
-        except:
-            return False
-
-
     def _load_raw_mail(self, path):
         with open(path, "rb") as f:
             raw_mail = f.read()
