@@ -9,7 +9,7 @@ from elasticsearch_dsl import DenseVector, Keyword, Long, Mapping, Nested
 
 from . import utils
 from .utils import ParserOutputType
-from ..settings import ELASTIC_BULK_BATCH_SIZE, ELASTIC_GLOBAL_TIMEOUT, ES_URL, FACE_VECTOR_FIELD_NAME, META_FIELD
+from ..settings import ELASTIC_BULK_BATCH_SIZE, ELASTIC_GLOBAL_TIMEOUT, ES_URL, META_FIELD
 
 
 logging.basicConfig(
@@ -46,16 +46,6 @@ class ESImporter:
         return main_version
 
 
-    @staticmethod
-    def check_face_analyzer_elegibility(elastic_url: str, minimum_licence="oss") -> bool:
-        version_number = ESImporter.version_number(elastic_url)
-        build_flavor = ESImporter.build_flavor(elastic_url)
-        if version_number >= 7 and build_flavor != minimum_licence:
-            return True
-        else:
-            return False
-
-
     def _importer_generator(self, generator, index_name: str):
         """
         Used to generate the payload for the Bulk API of the Python Elasticsearch Clients
@@ -80,7 +70,6 @@ class ESImporter:
         :return: As this is meant as the final part of the pipeline, this will only return True.
         """
         self._add_texta_facts_mapping(index_name)
-        self._add_texta_face_vectors_mapping(index_name)
         generator = self._importer_generator(generator, index_name)
         generator = list(generator)
         bulk(client=self.es, actions=generator, chunk_size=ELASTIC_BULK_BATCH_SIZE, refresh="wait_for")
@@ -124,7 +113,6 @@ class ESImporter:
                 self._try_add_file_url(mail, toolkit_url, tk_media_folder)
                 if has_mails_mapping is False:
                     self._add_texta_facts_mapping(mails_index)
-                    self._add_texta_face_vectors_mapping(mails_index)
                     has_mails_mapping = True
 
                 yield {
@@ -136,7 +124,6 @@ class ESImporter:
                 for attachment in attachments:
                     if has_attachments_mapping is False:
                         self._add_texta_facts_mapping(attachments_index)
-                        self._add_texta_face_vectors_mapping(attachments_index)
                         has_attachments_mapping = True
 
                     self._try_add_file_url(attachment, toolkit_url, tk_media_folder)
@@ -149,7 +136,6 @@ class ESImporter:
 
                 if has_index_mapping is False:
                     self._add_texta_facts_mapping(index_name)
-                    self._add_texta_face_vectors_mapping(index_name)
                     has_index_mapping = True
 
                 yield {
@@ -202,23 +188,6 @@ class ESImporter:
         self.es.indices.put_mapping(body=mapping, index=index, doc_type=doc_type, include_type_name=True)
 
 
-    def _add_texta_face_vectors_mapping(self, index):
-        face_analyzer_elegibility = ESImporter.check_face_analyzer_elegibility(ES_URL)
-        if face_analyzer_elegibility:
-            self.es.indices.create(index, ignore=[400, 404])
-            m = Mapping()
-            texta_face_vectors = Nested(
-                properties={
-                    "name": Keyword(),
-                    "vector": DenseVector(dims=128),
-                }
-            )
-            # Set the name of the field along with its mapping body
-            mapping = m.field(FACE_VECTOR_FIELD_NAME, texta_face_vectors).to_dict()
-            doc_type = self.get_doc_type_for_index(index)
-            self.es.indices.put_mapping(body=mapping, index=index, doc_type=doc_type, include_type_name=True)
-
-
     def _get_index_name(self, item):
         item_type = utils.get_output_type(item)
 
