@@ -6,11 +6,13 @@ from random import getrandbits
 
 from bs4 import BeautifulSoup
 
+from texta_parsers.settings import META_FIELD
+
 
 class HeaderParser:
     def __init__(self, msg):
         self.msg = msg
-        self.fails = {}
+        self.fails = []
 
 
     def parse(self):
@@ -50,7 +52,8 @@ class HeaderParser:
             return "", ""
         except:
             exc_type, value, _ = sys.exc_info()
-            self.fails["from"] = "{}: {}".format(exc_type.__name__, value)
+            error_message = "EmailParser - From - {}: {}".format(exc_type.__name__, value)
+            self.fails.append(error_message)
             return "", ""
 
 
@@ -73,7 +76,8 @@ class HeaderParser:
 
         except:
             exc_type, value, _ = sys.exc_info()
-            self.fails[field] = "{}: {}".format(exc_type.__name__, value)
+            error_message = "EmailParser - Address - {}: {}".format(exc_type.__name__, value)
+            self.fails.append(error_message)
             return ""
 
 
@@ -92,7 +96,8 @@ class HeaderParser:
 
             except:
                 exc_type, value, _ = sys.exc_info()
-                self.fails["subject"] = "{}: {}".format(exc_type.__name__, value)
+                error_message = "EmailParser - Subject - {}: {}".format(exc_type.__name__, value)
+                self.fails.append(error_message)
                 return ""
         else:
             return ""
@@ -131,14 +136,15 @@ class HeaderParser:
             return item_str
         except:
             exc_type, value, _ = sys.exc_info()
-            self.fails[field] = "{}: {}".format(exc_type.__name__, value)
+            error_message = "EmailParser - Decode - {}: {}".format(exc_type.__name__, value)
+            self.fails.append(error_message)
             return ""
 
 
 class BodyParser:
     def __init__(self, msg):
         self.msg = msg
-        self.fails = {}
+        self.fails = []
 
 
     def _parse_body_rec(self, msg):
@@ -166,7 +172,8 @@ class BodyParser:
             return self._parse_body_rec(self.msg)
         except:
             exc_type, value, _ = sys.exc_info()
-            self.fails["body"] = "{}: {}".format(exc_type.__name__, value)
+            error_message = "EmailParser - Body - {}: {}".format(exc_type.__name__, value)
+            self.fails.append(error_message)
             return ""
 
 
@@ -202,8 +209,10 @@ class BodyParser:
                     a_parser = AttachmentParser(payload, msg_id)
                     attachment_data = a_parser.parse()
 
-                    if a_parser.fails != {}:
-                        attachment_data["errors"] = a_parser.fails
+                    if a_parser.fails:
+                        attachment_data.setdefault(META_FIELD, {})
+                        attachment_data[META_FIELD].setdefault("errors", [])
+                        attachment_data[META_FIELD]["errors"].extend(a_parser.fails)
 
                     attachments_jsons.append(attachment_data)
                 elif payload.is_multipart() and payload.get_content_type() != "message/rfc822":
@@ -250,7 +259,8 @@ class AttachmentParser(BodyParser):
             return AttachmentParser.parse_filename(encoded_filename)
         except:
             exc_type, value, _ = sys.exc_info()
-            self.fails["filename"] = "{}: {}".format(exc_type.__name__, value)
+            error_message = "EmailParser - Filename - {}: {}".format(exc_type.__name__, value)
+            self.fails.append(error_message)
             return ""
 
 
