@@ -19,7 +19,7 @@ class MLPProcessor:
 
     def __init__(self, mlp):
         self.mlp = mlp
-        self.IGNORE_FIELDS = ("texta_facts", "properties", "texta_face_vectors")
+        self.IGNORE_FIELDS = ("texta_facts", "properties")
 
 
     def apply_mlp(self, generator, analyzers=["all"]):
@@ -44,7 +44,7 @@ class MLPProcessor:
             mlp_res = self.mlp.process(content, analyzers=analyzers)
             mlp_res_path = field + "_mlp"
             # Add the MLP output dictionary.
-            document[mlp_res_path] = mlp_res["text"]
+            document[mlp_res_path] = mlp_res["text_mlp"]
 
             facts = []
             for f in mlp_res["texta_facts"]:
