@@ -1,8 +1,16 @@
+import logging
 import os
 
 from texta_parsers.tools.extension import Extension
 
 
+logging.basicConfig(
+    format='%(levelname)s %(asctime)s: %(message)s',
+    datefmt='%d.%m.%Y %H:%M:%S',
+    level=logging.INFO
+)
+
+
 class DocScanner:
 
     def __init__(self):
@@ -20,11 +28,11 @@ class DocScanner:
             for filename in filenames:
                 file_path = os.path.join(dirpath, filename)
                 abspath = os.path.abspath(file_path)
-                print(abspath)
                 if abspath not in self.scanned_files:
                     self._save_path(abspath)
-                    print(abspath)
+                    logging.debug(f"Found file: '{abspath}', checking it's extension!")
                     if Extension.is_supported(abspath):
+                        logging.debug(f"Extension for file '{abspath}' is supported, yielding to the parser!")
                         yield abspath
 
 
@@ -41,7 +49,7 @@ class DocScanner:
         """
         Retrieves saved paths fron file.
         """
-        if(os.path.isfile(self.scanned_files_path) == True):
+        if (os.path.isfile(self.scanned_files_path) == True):
             with open(self.scanned_files_path, "r") as f:
                 files_dict = {path.strip(): True for path in f.readlines() if path}
             return files_dict
